@@ -22,7 +22,7 @@ package Astro::FITS::Header;
 #    Tim Jenness (t.jenness@jach.hawaii.edu)
 
 #  Revision:
-#     $Id: Header.pm,v 1.10 2001/10/19 20:28:55 allan Exp $
+#     $Id: Header.pm,v 1.8 2001/03/28 00:26:31 allan Exp $
 
 #  Copyright:
 #     Copyright (C) 2001 Particle Physics and Astronomy Research Council. 
@@ -55,13 +55,13 @@ use vars qw/ $VERSION /;
 
 use Astro::FITS::Header::Item;
 
-'$Revision: 1.10 $ ' =~ /.*:\s(.*)\s\$/ && ($VERSION = $1);
+'$Revision: 1.8 $ ' =~ /.*:\s(.*)\s\$/ && ($VERSION = $1);
 
 # C O N S T R U C T O R ----------------------------------------------------
 
 =head1 REVISION
 
-$Id: Header.pm,v 1.10 2001/10/19 20:28:55 allan Exp $
+$Id: Header.pm,v 1.8 2001/03/28 00:26:31 allan Exp $
 
 =head1 METHODS
 
@@ -105,8 +105,7 @@ sub new {
 
 =item B<item>
 
-Returns a FITS::Header:Item object referenced by index, C<undef> if it
-does not exist.
+Returns a FITS::Header:Item object referenced by index.
 
    $item = $header->item($index);
 
@@ -127,7 +126,7 @@ sub item {
 
 =item B<keyword>
 
-Returns keyword referenced by index, C<undef> if it does not exist.
+Returns keyword referenced by index.
 
    $keyword = $header->keyword($index);
 
@@ -148,46 +147,33 @@ sub keyword {
 
 =item B<itembyname>
 
-Returns an array of Header::Items for the requested keyword if called
-in list context, or an empty array if it does not exist.
+Returns an array of Header::Items for the requested keyword
 
    @items = $header->itembyname($keyword);
 
-If called in scalar context it returns the first item in the array, or
-C<undef> if the keyword does not exist.
-
-   $item = $header->itembyname($keyword);
-
-
-
 =cut
 
 sub itembyname {
    my ( $self, $keyword ) = @_;
             
-   # resolve the items from the index array from lookup table
-   my @items =
-     map { ${$self->{HEADER}}[$_] } @{${$self->{LOOKUP}}{$keyword}}
+   # grab the index array from lookup table
+   my @index;
+   @index = @{${$self->{LOOKUP}}{$keyword}}
          if ( exists ${$self->{LOOKUP}}{$keyword} && 
 	      defined ${$self->{LOOKUP}}{$keyword} );
    
-   return wantarray ?  @items : @items ? $items[0] : undef;
+   return map { ${$self->{HEADER}}[$_] } @index;
+
 }
 
 # I N D E X   --------------------------------------------------------------
 
 =item B<index>
 
-Returns an array of indices for the requested keyword if called in list
-context, or an empty array if it does not exist.
+Returns an array of indices for the requested keyword
 
    @index = $header->index($keyword);
 
-If called in scalar context it returns the first item in the array, or
-C<undef> if the keyword does not exist.
-
-   $index = $header->index($keyword);
-
 =cut
 
 sub index {
@@ -200,7 +186,7 @@ sub index {
 	      defined ${$self->{LOOKUP}}{$keyword} );
    
    # return the values array
-   return wantarray ? @index : @index ? $index[0] : undef;
+   return @index;
 
 }
 
@@ -208,27 +194,23 @@ sub index {
 
 =item B<value>
 
-Returns an array of values for the requested keyword if called
-in list context, or an empty array if it does not exist.
+Returns an array of values for the requested keyword
 
    @value = $header->value($keyword);
 
-If called in scalar context it returns the first item in the array, or
-C<undef> if the keyword does not exist.
-
 =cut
 
 sub value {
    my ( $self, $keyword ) = @_;
    
-   # resolve the values from the index array from lookup table
-   my @values =
-     map { ${$self->{HEADER}}[$_]->value() } @{${$self->{LOOKUP}}{$keyword}}
+   # grab the index array from lookup table
+   my @index;
+   @index = @{${$self->{LOOKUP}}{$keyword}}
          if ( exists ${$self->{LOOKUP}}{$keyword} && 
 	      defined ${$self->{LOOKUP}}{$keyword} );
 
    # loop over the indices and grab the values
-   return wantarray ? @values : @values ? $values[0] : undef;
+   return map { ${$self->{HEADER}}[$_]->value() }  @index;
    
 }
 
@@ -236,29 +218,23 @@ sub value {
 
 =item B<comment>
 
-Returns an array of comments for the requested keyword if called
-in list context, or an empty array if it does not exist.
+Returns an array of comments for the requested keyword
 
    @comment = $header->comment($keyword);
 
-If called in scalar context it returns the first item in the array, or
-C<undef> if the keyword does not exist.
-
-   $comment = $header->comment($keyword);
-
 =cut
 
 sub comment {
    my ( $self, $keyword ) = @_;
       
-   # resolve the comments from the index array from lookup table
-   my @comments =
-     map { ${$self->{HEADER}}[$_]->comment() } @{${$self->{LOOKUP}}{$keyword}}
+   # grab the index array from lookup table
+   my @index;
+   @index = @{${$self->{LOOKUP}}{$keyword}}
          if ( exists ${$self->{LOOKUP}}{$keyword} && 
 	      defined ${$self->{LOOKUP}}{$keyword} );
    
    # loop over the indices and grab the comments
-   return wantarray ?  @comments : @comments ? $comments[0] : undef;
+   return map { ${$self->{HEADER}}[$_]->comment() }  @index;
 }
 
 # I N S E R T -------------------------------------------------------------
@@ -377,9 +353,9 @@ sub replacebyname{
 
 Removes a FITS header card object by name
 
-  @card = $header->removebyname($keyword);
+  $card = $header->removebyname($keyword);
 
-returns the removed cards.
+returns the removed card.
 
 =cut
 
@@ -392,8 +368,6 @@ sub removebyname{
          if ( exists ${$self->{LOOKUP}}{$keyword} && 
 	      defined ${$self->{LOOKUP}}{$keyword} );
 
-   print "\@index = @index\n\n";
-   
    # loop over the keywords
    my @cards = map { splice @{$self->{HEADER}}, $_, 1; } @index;
 
@@ -465,24 +439,9 @@ Return the object contents as an array of FITS cards.
 
 sub cards {
   my $self = shift;
-  return map { "$_" } @{$self->{HEADER}};
+  return map { "$_"  } @{$self->{HEADER}};
 }
    
-# A L L I T E M S ---------------------------------------------------------   
- 
-=item B<allitems>
-
-Returns the header as an array of FITS::Header:Item objects.
-
-   @items = $header->allitems();
-
-=cut
-
-sub allitems {
-   my $self = shift;
-   return map { $_ } @{$self->{HEADER}};
-} 
-   
 # C O N F I G U R E -------------------------------------------------------
 
 =back
@@ -614,19 +573,20 @@ sub TIEHASH {
 # fetch key and value pair
 sub FETCH {
   my ($self, $key) = @_;
-  scalar $self->value($key);
+  my @values = $self->value($key);
+  return $values[0];
 }
 
 # store key and value pair
 sub STORE {
   my ($self, $keyword, $value) = @_;
   
-  my $item = $self->itembyname($keyword);
-  if (  defined $item ) {
-     $item->value($value);
+  my @items = $self->itembyname($keyword);
+  if ( exists $items[0] && defined $items[0] ) {
+     $items[0]->value($value);
   } else {
-     $item = new Astro::FITS::Header::Item( Keyword => $keyword,
-                                            Value => $value );
+     my $item = new Astro::FITS::Header::Item( Keyword => $keyword,
+                                               Value => $value );
      $self->insert(-1,$item);
   }
 
